@@ -5,25 +5,10 @@ from nipype import logging
 from nipype.pipeline import engine as pe
 from nipype.interfaces import utility as niu
 from niworkflows.engine.workflows import LiterateWorkflow as Workflow
-from ..fieldmaps import EstimatorType
-
 
 LOGGER = logging.getLogger("nipype.workflow")
 DEFAULT_MEMORY_MIN_GB = 0.01
 
-INPUT_FIELDS = {
-    EstimatorType.MAPPED: ["magnitude", "fieldmap"],
-    EstimatorType.PHASEDIFF: ["magnitude", "fieldmap"],
-    EstimatorType.PEPOLAR: ["metadata", "in_data"],
-    EstimatorType.ANAT: [
-        "epi_ref",
-        "epi_mask",
-        "anat_brain",
-        "std2anat_xfm",
-        "anat2bold_xfm",
-    ],
-}
-
 
 def init_fmap_preproc_wf(
     *,
@@ -67,7 +52,15 @@ def init_fmap_preproc_wf(
         The preprocessed fieldmap coefficients.
 
     """
+    from .fit.pepolar import INPUT_FIELDS as _pepolar_fields
+    from .fit.syn import INPUT_FIELDS as _syn_fields
     from .outputs import init_fmap_derivatives_wf, init_fmap_reports_wf
+    from ..fieldmaps import EstimatorType
+
+    INPUT_FIELDS = {
+        EstimatorType.ANAT: _syn_fields,
+        EstimatorType.PEPOLAR: _pepolar_fields,
+    }
 
     workflow = Workflow(name=name)
 
@@ -85,9 +78,11 @@ def init_fmap_preproc_wf(
         ]
     )
 
-    for n, estimator in enumerate(estimators):
+    for n, estimator in enumerate(estimators, 1):
         est_wf = estimator.get_workflow(omp_nthreads=omp_nthreads, debug=debug)
-        source_files = [str(f.path) for f in estimator.sources]
+        source_files = [
+            str(f.path) for f in estimator.sources if f.suffix not in ("T1w", "T2w")
+        ]
 
         out_map = pe.Node(
             niu.IdentityInterface(fields=out_fields), name=f"out_{estimator.bids_id}"
